==> libminigui-3.2.3.tar.gz: libminigui-3.2.3/src/sysres/icon/textfile.ico.c <==
/*
 *   This file is part of MiniGUI, a mature cross-platform windowing 
 *   and Graphics User Interface (GUI) support system for embedded systems
 *   and smart IoT devices.
 * 
 *   Copyright (C) 2002~2018, Beijing FMSoft Technologies Co., Ltd.
 *   Copyright (C) 1998~2002, WEI Yongming
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *   Or,
 * 
 *   As this program is a library, any link to this program must follow
 *   GNU General Public License version 3 (GPLv3). If you cannot accept
 *   GPLv3, you need to be licensed from FMSoft.
 * 
 *   If you have got a commercial license of this program, please use it
 *   under the terms and conditions of the commercial license.
 * 
 *   For more information about the commercial license, please refer to
 *   <http://www.minigui.com/en/about/licensing-policy/>.
 */

#include "common.h"

#ifdef _MGINCORE_RES

//data of "textfile.ico"

unsigned char _mgir_ico_textfile_data[]={
	0x00,0x00,0x01,0x00,0x02,0x00,0x10,0x10,	0x10,0x00,0x00,0x00,0x00,0x00,0x28,0x01,
	0x00,0x00,0x26,0x00,0x00,0x00,0x20,0x20,	0x10,0x00,0x00,0x00,0x00,0x00,0xE8,0x02,
	0x00,0x00,0x4E,0x01,0x00,0x00,0x28,0x00,	0x00,0x00,0x10,0x00,0x00,0x00,0x20,0x00,
	0x00,0x00,0x01,0x00,0x04,0x00,0x00,0x00,	0x00,0x00,0xC0,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x80,	0x00,0x00,0x00,0x80,0x80,0x00,0x80,0x00,
	0x00,0x00,0x80,0x00,0x80,0x00,0x80,0x80,	0x00,0x00,0xC0,0xC0,0xC0,0x00,0x80,0x80,
	0x80,0x00,0x00,0x00,0xFF,0x00,0x00,0xFF,	0x00,0x00,0x00,0xFF,0xFF,0x00,0xFF,0x00,
	0x00,0x00,0xFF,0x00,0xFF,0x00,0xFF,0xFF,	0x00,0x00,0xFF,0xFF,0xFF,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,
	0x44,0x44,0x40,0x00,0x00,0x00,0x4F,0xFF,	0x9F,0xFF,0x40,0x00,0x00,0x00,0x4F,0xF9,
	0x99,0xFF,0x40,0x00,0x00,0x00,0x4F,0x99,	0x79,0x9F,0x40,0x00,0x80,0x00,0x4F,0xFF,
	0xFF,0x99,0x40,0x00,0x00,0x00,0x4F,0x77,	0x77,0x79,0x40,0x00,0x08,0x08,0x4F,0xFF,
	0xFF,0xFF,0x40,0x00,0x00,0x00,0x4F,0x77,	0x7F,0xFF,0x40,0x00,0x08,0x00,0x4F,0xFF,
	0xF4,0x44,0x40,0x00,0x00,0x00,0x4F,0x77,	0xF4,0xF4,0x00,0x00,0x00,0x00,0x4F,0xFF,
	0xF4,0x40,0x00,0x00,0x00,0x00,0x44,0x44,	0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,
	0x00,0x00,0xFF,0xFF,0x00,0x00,0x00,0x7F,	0x00,0x00,0x00,0x7F,0x00,0x00,0x00,0x7F,
	0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x7F,	0x00,0x00,0x00,0x40,0x00,0x00,0x00,0x7F,
	0x00,0x00,0x00,0x61,0x00,0x00,0x00,0x7F,	0x00,0x00,0x00,0xFF,0x00,0x00,0x01,0xFF,
	0x00,0x00,0x03,0xFF,0x00,0x00,0xFF,0xFF,	0x00,0x00,0xFF,0xFF,0x00,0x00,0x28,0x00,
	0x00,0x00,0x20,0x00,0x00,0x00,0x40,0x00,	0x00,0x00,0x01,0x00,0x04,0x00,0x00,0x00,
	0x00,0x00,0x80,0x02,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x80,
	0x00,0x00,0x00,0x80,0x80,0x00,0x80,0x00,	0x00,0x00,0x80,0x00,0x80,0x00,0x80,0x80,
	0x00,0x00,0xC0,0xC0,0xC0,0x00,0x80,0x80,	0x80,0x00,0x00,0x00,0xFF,0x00,0x00,0xFF,
	0x00,0x00,0x00,0xFF,0xFF,0x00,0xFF,0x00,	0x00,0x00,0xFF,0x00,0xFF,0x00,0xFF,0xFF,
	0x00,0x00,0xFF,0xFF,0xFF,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,	0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xFF,	0xFF,0xFF,0x1F,0xFF,0xFF,0xFF,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xF7,	0x77,0x71,0x91,0x77,0x77,0x77,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xFF,	0xFF,0x19,0x99,0x1F,0xFF,0xFF,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xF7,	0x71,0x99,0x99,0x91,0x77,0x77,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xFF,	0xF9,0x99,0xF9,0x99,0x1F,0xFF,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xF7,	0x79,0x97,0x77,0x99,0x91,0x77,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xFF,	0xF9,0xFF,0xFF,0xF9,0x99,0x1F,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xF7,	0x77,0x77,0x77,0x77,0x99,0x91,0xFF,0x44,
	0x80,0x08,0x80,0x00,0x00,0x00,0x4F,0xFF,	0xFF,0xFF,0xFF,0xFF,0xF9,0x99,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xF7,	0x77,0x77,0x77,0x77,0x77,0x99,0xFF,0x40,
	0x80,0x00,0x08,0x00,0x80,0x00,0x4F,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xF9,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xF7,	0x77,0x77,0x77,0x77,0x77,0x77,0xFF,0x40,
	0x00,0x08,0x80,0x00,0x00,0x80,0x4F,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xF7,	0x77,0x77,0x77,0x77,0x77,0x77,0xFF,0x40,
	0x00,0x00,0x00,0x88,0x00,0x00,0x4F,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xF7,	0x77,0x77,0x77,0x77,0x77,0x77,0xFF,0x40,
	0x08,0x00,0x80,0x00,0x08,0x00,0x4F,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xF7,	0x77,0x77,0x77,0xFF,0xFF,0xFF,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xFF,	0xFF,0xFF,0xFF,0xFF,0x44,0x44,0x44,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xF7,	0x77,0x77,0x77,0xFF,0x4F,0xFF,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xFF,	0xFF,0xFF,0xFF,0xFF,0x4F,0xFF,0xF4,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xF7,	0x77,0x77,0x77,0xFF,0x4F,0xFF,0x40,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xFF,	0xFF,0xFF,0xFF,0xFF,0x4F,0xF4,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xFF,	0xFF,0xFF,0xFF,0xFF,0x4F,0x40,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,	0x44,0x44,0x44,0x44,0x44,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,	0x1F,0xFF,0x00,0x00,0x1F,0xFF,0x00,0x00,
	0x1F,0xFF,0x00,0x00,0x1F,0xFF,0x00,0x00,	0x1F,0xFF,0x00,0x00,0x1F,0xFF,0x00,0x00,
	0x1F,0xFF,0x00,0x00,0x1F,0xFF,0x00,0x00,	0x1F,0xFF,0x00,0x00,0x00,0x0F,0x00,0x00,
	0x1F,0xFF,0x00,0x00,0x10,0x03,0x00,0x00,	0x1F,0xFF,0x00,0x00,0x18,0x01,0x00,0x00,
	0x1F,0xFF,0x00,0x00,0x1E,0x07,0x00,0x00,	0x1F,0xFF,0x00,0x00,0x18,0x03,0x00,0x00,
	0x1F,0xFF,0x00,0x00,0x1F,0xFF,0x00,0x00,	0x1F,0xFF,0x00,0x00,0x1F,0xFF,0x00,0x00,
	0x3F,0xFF,0x00,0x00,0x7F,0xFF,0x00,0x00,	0xFF,0xFF,0x00,0x01,0xFF,0xFF,0x00,0x03,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF
};
#endif //_MGINCORE_RES

==> libminigui-4.0.2.tar.gz: libminigui-4.0.2/src/sysres/icon/textfile.ico.c <==
///////////////////////////////////////////////////////////////////////////////
//
//                          IMPORTANT NOTICE
//
// The following open source license statement does not apply to any
// entity in the Exception List published by FMSoft.
//
// For more information, please visit:
//
// https://www.fmsoft.cn/exception-list
//
//////////////////////////////////////////////////////////////////////////////
/*
 *   This file is part of MiniGUI, a mature cross-platform windowing 
 *   and Graphics User Interface (GUI) support system for embedded systems
 *   and smart IoT devices.
 * 
 *   Copyright (C) 2002~2018, Beijing FMSoft Technologies Co., Ltd.
 *   Copyright (C) 1998~2002, WEI Yongming
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *   Or,
 * 
 *   As this program is a library, any link to this program must follow
 *   GNU General Public License version 3 (GPLv3). If you cannot accept
 *   GPLv3, you need to be licensed from FMSoft.
 * 
 *   If you have got a commercial license of this program, please use it
 *   under the terms and conditions of the commercial license.
 * 
 *   For more information about the commercial license, please refer to
 *   <http://www.minigui.com/en/about/licensing-policy/>.
 */

#include "common.h"

#ifdef _MGINCORE_RES

//data of "textfile.ico"

const unsigned char _mgir_ico_textfile_data[]={
	0x00,0x00,0x01,0x00,0x02,0x00,0x10,0x10,	0x10,0x00,0x00,0x00,0x00,0x00,0x28,0x01,
	0x00,0x00,0x26,0x00,0x00,0x00,0x20,0x20,	0x10,0x00,0x00,0x00,0x00,0x00,0xE8,0x02,
	0x00,0x00,0x4E,0x01,0x00,0x00,0x28,0x00,	0x00,0x00,0x10,0x00,0x00,0x00,0x20,0x00,
	0x00,0x00,0x01,0x00,0x04,0x00,0x00,0x00,	0x00,0x00,0xC0,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x80,	0x00,0x00,0x00,0x80,0x80,0x00,0x80,0x00,
	0x00,0x00,0x80,0x00,0x80,0x00,0x80,0x80,	0x00,0x00,0xC0,0xC0,0xC0,0x00,0x80,0x80,
	0x80,0x00,0x00,0x00,0xFF,0x00,0x00,0xFF,	0x00,0x00,0x00,0xFF,0xFF,0x00,0xFF,0x00,
	0x00,0x00,0xFF,0x00,0xFF,0x00,0xFF,0xFF,	0x00,0x00,0xFF,0xFF,0xFF,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,
	0x44,0x44,0x40,0x00,0x00,0x00,0x4F,0xFF,	0x9F,0xFF,0x40,0x00,0x00,0x00,0x4F,0xF9,
	0x99,0xFF,0x40,0x00,0x00,0x00,0x4F,0x99,	0x79,0x9F,0x40,0x00,0x80,0x00,0x4F,0xFF,
	0xFF,0x99,0x40,0x00,0x00,0x00,0x4F,0x77,	0x77,0x79,0x40,0x00,0x08,0x08,0x4F,0xFF,
	0xFF,0xFF,0x40,0x00,0x00,0x00,0x4F,0x77,	0x7F,0xFF,0x40,0x00,0x08,0x00,0x4F,0xFF,
	0xF4,0x44,0x40,0x00,0x00,0x00,0x4F,0x77,	0xF4,0xF4,0x00,0x00,0x00,0x00,0x4F,0xFF,
	0xF4,0x40,0x00,0x00,0x00,0x00,0x44,0x44,	0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,
	0x00,0x00,0xFF,0xFF,0x00,0x00,0x00,0x7F,	0x00,0x00,0x00,0x7F,0x00,0x00,0x00,0x7F,
	0x00,0x00,0x00,0x03,0x00,0x00,0x00,0x7F,	0x00,0x00,0x00,0x40,0x00,0x00,0x00,0x7F,
	0x00,0x00,0x00,0x61,0x00,0x00,0x00,0x7F,	0x00,0x00,0x00,0xFF,0x00,0x00,0x01,0xFF,
	0x00,0x00,0x03,0xFF,0x00,0x00,0xFF,0xFF,	0x00,0x00,0xFF,0xFF,0x00,0x00,0x28,0x00,
	0x00,0x00,0x20,0x00,0x00,0x00,0x40,0x00,	0x00,0x00,0x01,0x00,0x04,0x00,0x00,0x00,
	0x00,0x00,0x80,0x02,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x80,0x00,0x00,0x80,
	0x00,0x00,0x00,0x80,0x80,0x00,0x80,0x00,	0x00,0x00,0x80,0x00,0x80,0x00,0x80,0x80,
	0x00,0x00,0xC0,0xC0,0xC0,0x00,0x80,0x80,	0x80,0x00,0x00,0x00,0xFF,0x00,0x00,0xFF,
	0x00,0x00,0x00,0xFF,0xFF,0x00,0xFF,0x00,	0x00,0x00,0xFF,0x00,0xFF,0x00,0xFF,0xFF,
	0x00,0x00,0xFF,0xFF,0xFF,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,	0x44,0x44,0x44,0x44,0x44,0x44,0x44,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xFF,	0xFF,0xFF,0x1F,0xFF,0xFF,0xFF,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xF7,	0x77,0x71,0x91,0x77,0x77,0x77,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xFF,	0xFF,0x19,0x99,0x1F,0xFF,0xFF,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xF7,	0x71,0x99,0x99,0x91,0x77,0x77,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xFF,	0xF9,0x99,0xF9,0x99,0x1F,0xFF,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xF7,	0x79,0x97,0x77,0x99,0x91,0x77,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xFF,	0xF9,0xFF,0xFF,0xF9,0x99,0x1F,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xF7,	0x77,0x77,0x77,0x77,0x99,0x91,0xFF,0x44,
	0x80,0x08,0x80,0x00,0x00,0x00,0x4F,0xFF,	0xFF,0xFF,0xFF,0xFF,0xF9,0x99,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xF7,	0x77,0x77,0x77,0x77,0x77,0x99,0xFF,0x40,
	0x80,0x00,0x08,0x00,0x80,0x00,0x4F,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xF9,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xF7,	0x77,0x77,0x77,0x77,0x77,0x77,0xFF,0x40,
	0x00,0x08,0x80,0x00,0x00,0x80,0x4F,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xF7,	0x77,0x77,0x77,0x77,0x77,0x77,0xFF,0x40,
	0x00,0x00,0x00,0x88,0x00,0x00,0x4F,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xF7,	0x77,0x77,0x77,0x77,0x77,0x77,0xFF,0x40,
	0x08,0x00,0x80,0x00,0x08,0x00,0x4F,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xF7,	0x77,0x77,0x77,0xFF,0xFF,0xFF,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xFF,	0xFF,0xFF,0xFF,0xFF,0x44,0x44,0x44,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xF7,	0x77,0x77,0x77,0xFF,0x4F,0xFF,0xFF,0x40,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xFF,	0xFF,0xFF,0xFF,0xFF,0x4F,0xFF,0xF4,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xF7,	0x77,0x77,0x77,0xFF,0x4F,0xFF,0x40,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xFF,	0xFF,0xFF,0xFF,0xFF,0x4F,0xF4,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x4F,0xFF,	0xFF,0xFF,0xFF,0xFF,0x4F,0x40,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x44,	0x44,0x44,0x44,0x44,0x44,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,	0x1F,0xFF,0x00,0x00,0x1F,0xFF,0x00,0x00,
	0x1F,0xFF,0x00,0x00,0x1F,0xFF,0x00,0x00,	0x1F,0xFF,0x00,0x00,0x1F,0xFF,0x00,0x00,
	0x1F,0xFF,0x00,0x00,0x1F,0xFF,0x00,0x00,	0x1F,0xFF,0x00,0x00,0x00,0x0F,0x00,0x00,
	0x1F,0xFF,0x00,0x00,0x10,0x03,0x00,0x00,	0x1F,0xFF,0x00,0x00,0x18,0x01,0x00,0x00,
	0x1F,0xFF,0x00,0x00,0x1E,0x07,0x00,0x00,	0x1F,0xFF,0x00,0x00,0x18,0x03,0x00,0x00,
	0x1F,0xFF,0x00,0x00,0x1F,0xFF,0x00,0x00,	0x1F,0xFF,0x00,0x00,0x1F,0xFF,0x00,0x00,
	0x3F,0xFF,0x00,0x00,0x7F,0xFF,0x00,0x00,	0xFF,0xFF,0x00,0x01,0xFF,0xFF,0x00,0x03,
	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF
};
#endif //_MGINCORE_RES
